@@ -1,4 +1,3 @@
-/* $Xorg: XSecurity.c,v 1.6 2001/02/09 02:03:49 xorgcvs Exp $ */
 /*
 
 Copyright 1996, 1998  The Open Group
@@ -24,7 +23,6 @@ used in advertising or otherwise to promote the sale, use or other dealings
 in this Software without prior written authorization from The Open Group.
 
 */
-/* $XFree86: xc/lib/Xext/XSecurity.c,v 1.5 2002/10/16 00:37:27 dawes Exp $ */
 
 #ifdef HAVE_CONFIG_H
 #include <config.h>
@@ -38,7 +36,7 @@ in this Software without prior written authorization from The Open Group.
 
 static XExtensionInfo _Security_info_data;
 static XExtensionInfo *Security_info = &_Security_info_data;
-static char *Security_extension_name = SECURITY_EXTENSION_NAME;
+static const char *Security_extension_name = SECURITY_EXTENSION_NAME;
 
 #define SecurityCheckExtension(dpy,i,val) \
   XextCheckExtension (dpy, i, Security_extension_name, val)
@@ -78,7 +76,7 @@ static XExtensionHooks Security_extension_hooks = {
     error_string                        /* error_string */
 };
 
-static char    *security_error_list[] = {
+static const char    *security_error_list[] = {
     "BadAuthorization",
     "BadAuthorizationProtocol"
 };
